@@ -15,7 +15,7 @@
 #include <limits.h>
 #include <time.h>
 
-#define VERSION "v0.29" // version info
+#define VERSION "v0.30" // version info
 #define HEIGHT 24 // height of the screen
 #define WIDTH 80 // width of the screen
 #define BOARD_HEIGHT (HEIGHT - 5) // height of the board
@@ -37,7 +37,7 @@ void handle_quit_signal(const int);
 unsigned char get_rand(const unsigned char);
 int main(int, char *[]);
 
-char quit, old_style_keys, hide_cursor_workaround, highscore_file_path[256], default_name[40];
+char quit, old_style_keys, counterclockwise_rotation, hide_cursor_workaround, highscore_file_path[256], default_name[40];
 
 unsigned long rseed;
 
